@@ -39,7 +39,8 @@ typedef enum {
 	COMPOSE_VCARD10,
 	COMPOSE_VCARD21,
 	COMPOSE_WAPINDICATOR,
-	COMPOSE_WAPSETTINGS
+	COMPOSE_WAPSETTINGS,
+	COMPOSE_USSD
 } ComposeType;
 
 typedef struct {
@@ -66,6 +67,7 @@ ComposeMapEntry ComposeMap[] = {
 	{"VCARD21", COMPOSE_VCARD21},
 	{"WAPINDICATOR", COMPOSE_WAPINDICATOR},
 	{"WAPSETTINGS", COMPOSE_WAPSETTINGS},
+	{"USSD", COMPOSE_USSD},
 	{NULL, 0}
 };
 
@@ -228,6 +230,10 @@ GSM_Error CreateMessage(GSM_Message_Type *type, GSM_MultiSMSMessage *sms, int ar
 		SMSInfo.UnicodeCoding   		= FALSE;
 		SMSInfo.EntriesNum 			= 0;
 		break;
+	case COMPOSE_USSD:
+		SMSInfo.Entries[0].ID = SMS_USSD;
+		SMSInfo.Class = GSM_SMS_USSD;
+		break;
 	case COMPOSE_MMSINDICATOR:
 		if (argc < 3 + startarg) {
 			printf("%s\n", _("Where are parameters?"));
@@ -414,13 +420,13 @@ GSM_Error CreateMessage(GSM_Message_Type *type, GSM_MultiSMSMessage *sms, int ar
 			case WAPSETTINGS_BEARER_GPRS:
 				if (strcasecmp(argv[2 + startarg],"GPRS") == 0) {
 					SMSInfo.Entries[0].Settings = &Backup.WAPSettings[i]->Settings[j];
-					break;
 				}
+				break;
 			case WAPSETTINGS_BEARER_DATA:
 				if (strcasecmp(argv[2 + startarg],"DATA") == 0) {
 					SMSInfo.Entries[0].Settings = &Backup.WAPSettings[i]->Settings[j];
-					break;
 				}
+				break;
 			default:
 				break;
 			}
