@@ -120,6 +120,9 @@ int bluetooth_checkservicename(GSM_StateMachine *s, const char *name)
 		if (strstr(name, "SerialPort1") != NULL) return 3;
 		if (strstr(name, "SerialPort") != NULL) return 2;
 
+		/* MyPhoneExplorer client on Android */
+		if (strstr(name, "MyPhoneExplorer") != NULL) return 1;
+
 		if (strstr(name, "COM1") != NULL) return 3;
 		if (strstr(name, "COM") != NULL) return 1;
 	}
@@ -211,7 +214,7 @@ GSM_Error lock_device(GSM_StateMachine *s, const char* port, char **lock_name)
 	char 		*lock_file = NULL;
 	char 		buffer[max_buf_len];
 	const char 	*aux;
-	int 		fd, len;
+	int 		fd = -1, len;
 	GSM_Error	error = ERR_NONE;
 	size_t wrotebytes;
 	char 	buf[max_buf_len];
@@ -271,6 +274,8 @@ GSM_Error lock_device(GSM_StateMachine *s, const char* port, char **lock_name)
 			buf[n] = 0;
 			sscanf(buf, "%d", &pid);
 		}
+		close(fd);
+		fd = -1;
 
 
 		if (pid > 0 && kill((pid_t)pid, 0) < 0 && errno == ESRCH) {
@@ -309,6 +314,7 @@ GSM_Error lock_device(GSM_StateMachine *s, const char* port, char **lock_name)
 	sprintf(buffer, "%10ld gammu\n", (long)getpid());
 	wrotebytes = write(fd, buffer, strlen(buffer));
 	close(fd);
+	fd = -1;
 	if (wrotebytes != strlen(buffer)) {
 		error = ERR_WRITING_FILE;
 		goto failed;
@@ -321,6 +327,9 @@ failread:
 	smprintf(s, "Cannot lock device\n");
 	error = ERR_UNKNOWN;
 failed:
+	if (fd != -1) {
+		close(fd);
+	}
 	free(lock_file);
 	*lock_name = NULL;
 	return error;
