@@ -889,7 +889,7 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message *msg, GSM_StateMachine *
 						}
 						break;
 					}
-					FALLTHROUGH;
+					FALLTHROUGH
 				case SMS_Coding_Unicode_No_Compression:
 				case SMS_Coding_8bit:
 					if ((firstbyte & 0x40)==0x40 && GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SMS_UTF8_ENCODED)) {
@@ -1717,7 +1717,7 @@ GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsig
 				}
 				break;
 			}
-			FALLTHROUGH;
+			FALLTHROUGH
 	        case SMS_Coding_Unicode_No_Compression:
 	        case SMS_Coding_8bit:
 			error = PHONE_EncodeSMSFrame(s,message,buffer,PHONE_SMSDeliver,current,TRUE);
