@@ -21,6 +21,7 @@ const GSM_CodeName GSM_Countries[] = {
 	{"218", "Bosnia and Herzegovina"},
 	{"219", "Croatia"},
 	{"220", "Serbia"},
+	{"221", "Kosovo"},
 	{"222", "Italy"},
 	{"225", "Vatican"},
 	{"226", "Romania"},
@@ -82,6 +83,7 @@ const GSM_CodeName GSM_Countries[] = {
 	{"334", "Mexico"},
 	{"338", "Bermuda"},
 	{"338", "Jamaica"},
+	{"338", "Saint Lucia"},
 	{"338", "Turks and Caicos Islands"},
 	{"340", "French Antilles"},
 	{"342", "Barbados"},
@@ -173,6 +175,7 @@ const GSM_CodeName GSM_Countries[] = {
 	{"551", "Marshall Islands"},
 	{"552", "Palau"},
 	{"553", "Tuvalu"},
+	{"554", "Tokelau"},
 	{"555", "Niue"},
 	{"602", "Egypt"},
 	{"603", "Algeria"},
@@ -218,7 +221,7 @@ const GSM_CodeName GSM_Countries[] = {
 	{"643", "Mozambique"},
 	{"645", "Zambia"},
 	{"646", "Madagascar"},
-	{"647", "French Guiana"},
+	{"647", "French Indian Ocean Territories"},
 	{"648", "Zimbabwe"},
 	{"649", "Namibia"},
 	{"650", "Malawi"},
@@ -265,7 +268,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"202 01", "Cosmote"},
 	{"202 02", "Cosmote"},
 	{"202 03", "OTE"},
-	{"202 04", "OTE"},
+	{"202 04", "OSE"},
 	{"202 05", "Vodafone"},
 	{"202 06", "Cosmoline"},
 	{"202 07", "AMD Telecom"},
@@ -299,7 +302,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"204 20", "T-Mobile"},
 	{"204 21", "ProRail B.V."},
 	{"204 22", "Ministerie van Defensie"},
-	{"204 23", "ASPIDER Solutions Nederland B.V."},
+	{"204 23", "Wyless Nederland B.V."},
 	{"204 24", "Private Mobility Nederland B.V."},
 	{"204 25", "CapX B.V."},
 	{"204 26", "SpeakUp B.V."},
@@ -324,7 +327,9 @@ const GSM_CodeName GSM_Networks[] = {
 	{"206 09", "Voxbone"},
 	{"206 10", "Orange"},
 	{"206 15", "Elephant Talk Communications Schweiz GmbH"},
+	{"206 16", "NextGen Mobile Ltd."},
 	{"206 20", "BASE"},
+	{"206 25", "Voyacom SPRL"},
 	{"206 40", "JOIN"},
 	{"208 01", "Orange"},
 	{"208 02", "Orange"},
@@ -339,11 +344,12 @@ const GSM_CodeName GSM_Networks[] = {
 	{"208 11", "SFR"},
 	{"208 12", "Hewlett-Packard France"},
 	{"208 13", "SFR"},
-	{"208 14", "RFF"},
+	{"208 14", "SNCF Reseau "},
 	{"208 15", "Free Mobile"},
 	{"208 16", "Free Mobile"},
 	{"208 17", "LEGOS"},
 	{"208 18", "Voxbone"},
+	{"208 19", "Altitude Infrastructure"},
 	{"208 20", "Bouygues"},
 	{"208 21", "Bouygues"},
 	{"208 22", "Transatel Mobile"},
@@ -351,23 +357,26 @@ const GSM_CodeName GSM_Networks[] = {
 	{"208 24", "MobiquiThings"},
 	{"208 25", "LycaMobile"},
 	{"208 26", "NRJ Mobile"},
-	{"208 27", "Afone"},
+	{"208 27", "Coriolis Telecom"},
 	{"208 28", "Airbus Defence and Space SAS"},
 	{"208 29", "Societe International Mobile Communication"},
-	{"208 30", "Symacom"},
+	{"208 30", "Syma Mobile"},
 	{"208 31", "Vectone Mobile"},
 	{"208 88", "Bouygues"},
 	{"208 89", "Fondation b-com"},
 	{"208 90", "Images & Reseaux"},
 	{"208 91", "Orange S.A."},
 	{"208 92", "Com4Innov"},
-	{"208 93", "TDF"},
+	{"208 93", "Thales Communications & Security SAS"},
 	{"208 94", "Halys"},
-	{"212 01", "Office des Telephones"},
-	{"212 01", "Vala"},
-	{"212 01", "Z Mobile"},
+	{"208 95", "Orange S.A."},
+	{"208 96", "Axione"},
+	{"208 97", "Thales Communications & Security SAS"},
+	{"208 98", "Societe Air France"},
+	{"212 10", "Office des Telephones"},
 	{"213 03", "Mobiland"},
 	{"214 01", "Vodafone"},
+	{"214 02", "Altecom/Fibracat"},
 	{"214 03", "Orange"},
 	{"214 04", "Yoigo"},
 	{"214 05", "Movistar"},
@@ -375,8 +384,8 @@ const GSM_CodeName GSM_Networks[] = {
 	{"214 07", "Movistar"},
 	{"214 08", "Euskaltel"},
 	{"214 09", "Orange"},
-	{"214 10", "Operadora de Telecomunicaciones Opera SL"},
-	{"214 11", "Orange"},
+	{"214 10", "ZINNIA TELECOMUNICACIONES, S.L.U."},
+	{"214 11", "TELECOM CASTILLA-LA MANCHA, S.A."},
 	{"214 12", "Contacta Servicios Avanzados de Telecomunicaciones SL"},
 	{"214 13", "Incotel Ingeniera y Consultaria SL"},
 	{"214 14", "Incotel Servicioz Avanzados SL"},
@@ -406,6 +415,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"216 01", "Telenor Hungary"},
 	{"216 02", "MVM Net Ltd."},
 	{"216 03", "DIGI"},
+	{"216 04", "Invitech Solutions"},
 	{"216 30", "T-Mobile"},
 	{"216 70", "Vodafone"},
 	{"216 71", "upc"},
@@ -425,6 +435,9 @@ const GSM_CodeName GSM_Networks[] = {
 	{"220 07", "Orion Telekom"},
 	{"220 09", "Vectone Mobile"},
 	{"220 11", "GLOBALTEL d.o.o."},
+	{"221 01", "Vala"},
+	{"221 02", "IPKO"},
+	{"221 06", "Z Mobile"},
 	{"222 01", "TIM"},
 	{"222 02", "Elsacom"},
 	{"222 04", "Intermatica"},
@@ -443,6 +456,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"222 39", "SMS Italia"},
 	{"222 43", "TIM"},
 	{"222 48", "TIM"},
+	{"222 50", "Ho"},
 	{"222 77", "IPSE 2000"},
 	{"222 88", "Wind"},
 	{"222 98", "BLU"},
@@ -475,13 +489,15 @@ const GSM_CodeName GSM_Networks[] = {
 	{"228 56", "SMSRelay AG"},
 	{"228 57", "Mitto AG"},
 	{"228 58", "beeone"},
+	{"228 59", "Vectone"},
 	{"228 60", "Sunrise"},
+	{"228 61", "Compatel Ltd."},
 	{"228 99", "Swisscom"},
 	{"230 01", "T-Mobile"},
 	{"230 02", "O2"},
 	{"230 03", "Vodafone"},
-	{"230 04", "U:fon"},
-	{"230 05", "TRAVEL TELEKOMMUNIKATION, s.r.o."},
+	{"230 04", "Nordic Telecom s.r.o."},
+	{"230 05", "PODA a.s."},
 	{"230 06", "OSNO TELECOMUNICATION, s.r.o."},
 	{"230 07", "ASTELNET, s.r.o."},
 	{"230 08", "Compatel s.r.o."},
@@ -494,6 +510,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"231 04", "Telekom"},
 	{"231 05", "Orange"},
 	{"231 06", "O2"},
+	{"231 07", "Towercom, a. s."},
 	{"231 99", "ZSR"},
 	{"232 01", "A1.net"},
 	{"232 02", "A1 Telekom Austria"},
@@ -514,13 +531,17 @@ const GSM_CodeName GSM_Networks[] = {
 	{"232 17", "MASS Response Service GmbH"},
 	{"232 18", "smartspace GmbH"},
 	{"232 19", "Tele2 Telecommunication GmbH"},
-	{"232 20", "MTEL Austrija GmbH"},
+	{"232 20", "m:tel"},
+	{"232 21", "Salzburg AG fur Energie, Verkehr und Telekommunikation"},
+	{"232 22", "Plintron Austria Limited"},
 	{"232 91", "GSM-R A"},
 	{"232 92", "ArgoNET"},
 	{"234 00", "BT"},
 	{"234 01", "Vectone Mobile"},
 	{"234 02", "O2 (UK)"},
 	{"234 03", "Airtel-Vodafone"},
+	{"234 03", "Airtel-Vodafone"},
+	{"234 03", "Airtel-Vodafone"},
 	{"234 04", "FMS Solutions Ltd"},
 	{"234 05", "COLT Mobile Telecommunications Limited"},
 	{"234 06", "Internet Computer Bureau Limited"},
@@ -556,6 +577,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"234 34", "Orange"},
 	{"234 35", "JSC Ingenium (UK) Limited"},
 	{"234 36", "Sure Mobile"},
+	{"234 36", "Sure Mobile"},
 	{"234 37", "Synectiv Ltd"},
 	{"234 38", "Virgin Mobile"},
 	{"234 39", "Gamma Telecom Holdings Ltd."},
@@ -565,14 +587,18 @@ const GSM_CodeName GSM_Networks[] = {
 	{"234 51", "Relish"},
 	{"234 52", "Shyam Telecom UK Ltd"},
 	{"234 53", "Limitless Mobile Ltd"},
-	{"234 54", "The Carphone Warehouse Limited"},
+	{"234 54", "iD Mobile"},
+	{"234 55", "Sure Mobile"},
 	{"234 55", "Sure Mobile"},
 	{"234 55", "Sure Mobile"},
 	{"234 56", "CESG"},
 	{"234 57", "Sky UK Limited"},
 	{"234 58", "Pronto GSM"},
+	{"234 58", "Pronto GSM"},
 	{"234 59", "Limitless Mobile Ltd"},
 	{"234 70", "AMSUK Ltd."},
+	{"234 71", "Home Office"},
+	{"234 72", "Hanhaa Limited"},
 	{"234 76", "BT"},
 	{"234 78", "Airwave"},
 	{"234 86", "EE"},
@@ -587,7 +613,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"235 95", "Network Rail Infrastructure Limited"},
 	{"238 01", "TDC"},
 	{"238 02", "Telenor"},
-	{"238 03", "MACH Connectivity"},
+	{"238 03", "Syniverse Technologies"},
 	{"238 04", "NextGen Mobile Ltd T/A CardBoardFish"},
 	{"238 05", "TetraNet"},
 	{"238 06", "3"},
@@ -605,12 +631,14 @@ const GSM_CodeName GSM_Networks[] = {
 	{"238 18", "Cubic Telecom"},
 	{"238 20", "Telia"},
 	{"238 23", "GSM-R DK"},
-	{"238 28", "CoolTEL ApS"},
+	{"238 25", "Viahub"},
+	{"238 28", "LINK Mobile A/S"},
 	{"238 30", "Interactive digital media GmbH"},
 	{"238 40", "Ericsson Danmark A/S"},
-	{"238 42", "Brandtel ApS"},
+	{"238 42", "Tel42 ApS"},
 	{"238 43", "MobiWeb Limited"},
 	{"238 66", "TT-Netvaerket P/S"},
+	{"238 73", "Onomondo ApS"},
 	{"238 77", "Telenor"},
 	{"240 01", "Telia"},
 	{"240 02", "3"},
@@ -637,9 +665,9 @@ const GSM_CodeName GSM_Networks[] = {
 	{"240 23", "Infobip Limited (UK)"},
 	{"240 24", "Sweden 2G"},
 	{"240 25", "Monty UK Global Ltd"},
-	{"240 26", "Beepsend AB"},
+	{"240 26", "Twilio Sweden AB"},
 	{"240 27", "GlobeTouch AB"},
-	{"240 28", "CoolTEL Aps"},
+	{"240 28", "LINK Mobile A/S"},
 	{"240 29", "Mercury International Carrier Services"},
 	{"240 30", "NextGen Mobile Ltd."},
 	{"240 31", "RebTel Network AB"},
@@ -651,13 +679,16 @@ const GSM_CodeName GSM_Networks[] = {
 	{"240 37", "CLX Networks AB"},
 	{"240 38", "Voxbone"},
 	{"240 39", "Borderlight AB"},
-	{"240 40", "ReWiCom Scandinavia AB"},
+	{"240 40", "North net connect AB"},
 	{"240 41", "Shyam Telecom UK Ltd."},
 	{"240 42", "Telenor Connexion AB"},
 	{"240 43", "MobiWeb Ltd."},
-	{"240 44", "Limitless Mobile AB"},
+	{"240 44", "Telenabler AB"},
 	{"240 45", "Spirius AB"},
+	{"240 46", "Viahub"},
+	{"240 47", "Viatel Sweden AB"},
 	{"240 60", "Telefonaktiebolaget LM Ericsson"},
+	{"240 61", "MessageBird B.V."},
 	{"242 01", "Telenor"},
 	{"242 02", "Telia"},
 	{"242 03", "Televerket AS"},
@@ -700,6 +731,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"244 25", "Datame"},
 	{"244 26", "Compatel"},
 	{"244 27", "Teknologian tutkimuskeskus VTT Oy"},
+	{"244 28", "Teknologian tutkimuskeskus VTT Oy"},
 	{"244 29", "SCNL Truphone"},
 	{"244 30", "Vectone Mobile"},
 	{"244 31", "Kuiri"},
@@ -713,9 +745,10 @@ const GSM_CodeName GSM_Networks[] = {
 	{"244 39", "Nokia Solutions and Networks Oy"},
 	{"244 40", "Nokia Solutions and Networks Oy"},
 	{"244 41", "Nokia Solutions and Networks Oy"},
+	{"244 42", "SMS Provider Corp."},
 	{"244 91", "Sonera"},
 	{"244 92", "Sonera"},
-	{"246 01", "Omnitel"},
+	{"246 01", "Telia"},
 	{"246 02", "BITE"},
 	{"246 03", "Tele2"},
 	{"246 04", "LR vidaus reikalu ministerija (Ministry of the Interior)"},
@@ -723,6 +756,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"246 06", "Mediafon"},
 	{"246 07", "Compatel Ltd."},
 	{"246 08", "MEZON"},
+	{"246 09", "Interactive Digital Media GmbH"},
 	{"247 01", "LMT"},
 	{"247 02", "Tele2"},
 	{"247 03", "TRIATEL"},
@@ -731,7 +765,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"247 06", "Rigatta"},
 	{"247 07", "MTS"},
 	{"247 08", "IZZI"},
-	{"247 09", "Camel Mobile"},
+	{"247 09", "Xomobile"},
 	{"248 01", "Telia"},
 	{"248 02", "Elisa"},
 	{"248 03", "Tele2"},
@@ -750,6 +784,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"250 05", "ETK"},
 	{"250 06", "Skylink"},
 	{"250 07", "SMARTS"},
+	{"250 08", "Vainah Telecom"},
 	{"250 09", "Skylink"},
 	{"250 10", "DTC"},
 	{"250 11", "Yota"},
@@ -763,9 +798,11 @@ const GSM_CodeName GSM_Networks[] = {
 	{"250 18", "Osnova Telecom"},
 	{"250 19", "INDIGO"},
 	{"250 20", "Tele2"},
+	{"250 21", "GlobalTel"},
 	{"250 22", "Vainakh Telecom"},
-	{"250 23", "Mobicom - Novosibirsk"},
+	{"250 23", "Thuraya"},
 	{"250 28", "Beeline"},
+	{"250 29", "Iridium"},
 	{"250 32", "Win Mobile"},
 	{"250 33", "Sevmobile"},
 	{"250 34", "Krymtelekom"},
@@ -776,6 +813,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"250 50", "MTS"},
 	{"250 54", "TTK"},
 	{"250 60", "Volna mobile"},
+	{"250 62", "Tinkoff Mobile"},
 	{"250 811", "Votek Mobile"},
 	{"250 91", "Sonic Duo"},
 	{"250 92", "Primtelefon"},
@@ -795,7 +833,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"257 02", "MTS"},
 	{"257 03", "DIALLOG"},
 	{"257 04", "life:)"},
-	{"257 05", "Beltelecom"},
+	{"257 05", "byfly"},
 	{"257 06", "beCloud"},
 	{"259 01", "Orange"},
 	{"259 02", "Moldcell"},
@@ -803,6 +841,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"259 03", "Unite"},
 	{"259 04", "Eventis"},
 	{"259 05", "Unite"},
+	{"259 15", "IDC"},
 	{"259 99", "Unite"},
 	{"260 01", "Plus"},
 	{"260 02", "T-Mobile"},
@@ -819,7 +858,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"260 13", "Sferia"},
 	{"260 14", "Sferia"},
 	{"260 15", "Aero2"},
-	{"260 16", "Mobyland"},
+	{"260 16", "Aero2"},
 	{"260 17", "Aero2"},
 	{"260 18", "AMD Telecom"},
 	{"260 19", "Teleena"},
@@ -827,8 +866,8 @@ const GSM_CodeName GSM_Networks[] = {
 	{"260 21", "Exteri"},
 	{"260 22", "Arcomm"},
 	{"260 23", "Amicomm"},
-	{"260 24", "WideNet"},
-	{"260 25", "BS&T"},
+	{"260 24", "IT Partners Telco Sp. z o.o."},
+	{"260 25", "Polskie Sieci Radiowe Sp. z o.o. Sp. k.a."},
 	{"260 26", "ATE"},
 	{"260 27", "Intertelcom"},
 	{"260 28", "PhoneNet"},
@@ -852,12 +891,13 @@ const GSM_CodeName GSM_Networks[] = {
 	{"260 46", "Terra Telekom Sp. z o.o."},
 	{"260 47", "SMShighway Limited"},
 	{"260 48", "AGILE TELECOM S.P.A."},
+	{"260 49", "Messagebird B.V."},
 	{"260 98", "Play"},
 	{"262 01", "Telekom"},
 	{"262 02", "Vodafone"},
-	{"262 03", "E-Plus"},
+	{"262 03", "O2"},
 	{"262 04", "Vodafone"},
-	{"262 05", "E-Plus"},
+	{"262 05", "O2"},
 	{"262 06", "Telekom"},
 	{"262 07", "O2"},
 	{"262 08", "O2"},
@@ -869,12 +909,13 @@ const GSM_CodeName GSM_Networks[] = {
 	{"262 14", "Group 3G UMTS"},
 	{"262 15", "Airdata"},
 	{"262 16", "Telogic Germany GmbH"},
-	{"262 17", "E-Plus"},
+	{"262 17", "O2"},
 	{"262 18", "NetCologne"},
 	{"262 19", "Inquam Deutschland"},
-	{"262 20", "OnePhone"},
+	{"262 20", "Voiceworks"},
 	{"262 21", "Multiconnect GmbH"},
 	{"262 22", "sipgate Wireless GmbH"},
+	{"262 23", "Drillisch Online AG"},
 	{"262 33", "simquadrat"},
 	{"262 41", "First Telecom GmbH"},
 	{"262 42", "CCC Event"},
@@ -885,7 +926,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"262 74", "Qualcomm CDMA Technologies GmbH"},
 	{"262 75", "Core Network Dynamics GmbH"},
 	{"262 76", "Siemens AG"},
-	{"262 77", "E-Plus"},
+	{"262 77", "O2"},
 	{"262 78", "Telekom"},
 	{"262 79", "ng4T GmbH"},
 	{"262 901", "Debitel"},
@@ -901,26 +942,33 @@ const GSM_CodeName GSM_Networks[] = {
 	{"268 06", "MEO"},
 	{"268 07", "Vectone Mobile"},
 	{"268 11", "Compatel, Limited"},
-	{"268 12", "Refer Telecom - Servicos de Telecomunicacoes, S.A."},
+	{"268 12", "IP Telecom - Servicos de Telecomunicacoes, S.A."},
+	{"268 13", "G9Telecom, S.A."},
 	{"268 21", "Zapp"},
 	{"268 80", "MEO"},
 	{"270 01", "POST"},
 	{"270 02", "MTX Connect S.a.r.l."},
+	{"270 07", "Bouygues Telecom S.A."},
 	{"270 10", "Blue Communications"},
 	{"270 77", "Tango"},
 	{"270 78", "Interactive digital media GmbH"},
+	{"270 79", "Mitto A.G."},
+	{"270 80", "Syniverse Technologies S.a r.l."},
+	{"270 81", "E-Lux Mobile Telecommunication S.A."},
 	{"270 99", "Orange"},
 	{"272 01", "Vodafone"},
 	{"272 02", "3"},
-	{"272 03", "Meteor"},
+	{"272 03", "Eir"},
 	{"272 04", "Access Telecom"},
 	{"272 05", "3"},
-	{"272 07", "eMobile"},
-	{"272 09", "Clever Communications"},
+	{"272 07", "Eir"},
+	{"272 08", "Eir"},
+	{"272 09", "Clever Communications Ltd."},
 	{"272 11", "Tesco Mobile"},
 	{"272 13", "Lycamobile"},
 	{"272 15", "Virgin Mobile"},
 	{"272 16", "Carphone Warehouse"},
+	{"272 17", "3"},
 	{"274 01", "Siminn"},
 	{"274 02", "Vodafone"},
 	{"274 03", "Vodafone"},
@@ -931,7 +979,9 @@ const GSM_CodeName GSM_Networks[] = {
 	{"274 08", "On-waves"},
 	{"274 11", "Nova"},
 	{"274 12", "Tal"},
+	{"274 16", "Tismi BV"},
 	{"274 22", "Landhelgisgaeslan (Icelandic Coast Guard)"},
+	{"274 31", "Siminn"},
 	{"276 01", "Telekom.al"},
 	{"276 02", "Vodafone"},
 	{"276 03", "Eagle Mobile"},
@@ -980,15 +1030,15 @@ const GSM_CodeName GSM_Networks[] = {
 	{"292 01", "PRIMA"},
 	{"293 10", "SZ - Infrastruktura, d.o.o."},
 	{"293 20", "COMPATEL Ltd"},
-	{"293 40", "Si.mobil"},
+	{"293 40", "A1"},
 	{"293 41", "D3 Mobile"},
 	{"293 41", "IPKO"},
 	{"293 41", "Mobitel"},
 	{"293 64", "T-2"},
 	{"293 70", "Telemach"},
 	{"294 01", "Telekom.mk"},
-	{"294 02", "ONE"},
-	{"294 03", "Vip MK"},
+	{"294 02", "vip"},
+	{"294 03", "vip"},
 	{"294 04", "Lycamobile"},
 	{"294 10", "WTI Macedonia"},
 	{"294 11", "MOBIK TELEKOMUNIKACII DOOEL Skopje"},
@@ -1003,6 +1053,8 @@ const GSM_CodeName GSM_Networks[] = {
 	{"297 01", "Telenor"},
 	{"297 02", "T-Mobile"},
 	{"297 03", "m:tel CG"},
+	{"302 130", "Xplornet"},
+	{"302 131", "Xplornet"},
 	{"302 220", "Telus Mobility, Koodo Mobile, Public Mobile"},
 	{"302 221", "Telus"},
 	{"302 222", "Telus"},
@@ -1024,6 +1076,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"302 510", "Videotron"},
 	{"302 520", "Videotron"},
 	{"302 530", "Keewaytinook Mobile"},
+	{"302 540", "Rovvr Communications Inc."},
 	{"302 560", "Lynx Mobility"},
 	{"302 570", "LightSquared"},
 	{"302 590", "Quadro Mobility"},
@@ -1031,6 +1084,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"302 620", "ICE Wireless"},
 	{"302 630", "Aliant Mobility"},
 	{"302 640", "Bell"},
+	{"302 650", "TBaytel"},
 	{"302 652", "BC Tel Mobility (Telus)"},
 	{"302 653", "Telus"},
 	{"302 655", "MTS"},
@@ -1049,7 +1103,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"302 740", "Shaw Telecom"},
 	{"302 750", "SaskTel"},
 	{"302 760", "Public Mobile"},
-	{"302 770", "Rural Com"},
+	{"302 770", "TNW Wireless"},
 	{"302 780", "SaskTel"},
 	{"302 790", "NetSet Communications"},
 	{"302 820", "Rogers Wireless"},
@@ -1057,6 +1111,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"302 880", "Bell / Telus / SaskTel"},
 	{"302 920", "Rogers Wireless"},
 	{"302 940", "Wightman Mobility"},
+	{"302 990", ""},
 	{"308 01", "Ameris"},
 	{"308 02", "GLOBALTEL"},
 	{"310 004", "Verizon"},
@@ -1104,7 +1159,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"310 230", "T-Mobile"},
 	{"310 240", "T-Mobile"},
 	{"310 250", "T-Mobile"},
-	{"310 260", "T-Mobile USA"},
+	{"310 260", "T-Mobile"},
 	{"310 270", "T-Mobile"},
 	{"310 280", "AT&T"},
 	{"310 290", "nep"},
@@ -1200,7 +1255,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"311 120", "iConnect"},
 	{"311 120", "iConnect"},
 	{"311 130", "Lightsquared L.P."},
-	{"311 140", "Sprocket Wireless"},
+	{"311 140", "Bravado Wireless"},
 	{"311 150", "Wilkes Cellular"},
 	{"311 160", "Lightsquared L.P."},
 	{"311 170", "Broadpoint Inc."},
@@ -1252,7 +1307,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"311 440", "Bluegrass Cellular LLC"},
 	{"311 450", "PTCI"},
 	{"311 460", "Fisher Wireless Services Inc."},
-	{"311 470", "Innovative Wireless"},
+	{"311 470", "Viya"},
 	{"311 480", "Verizon"},
 	{"311 481", "Verizon"},
 	{"311 482", "Verizon"},
@@ -1316,7 +1371,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"311 990", "VTel Wireless"},
 	{"312 010", "Chariton Valley"},
 	{"312 020", "Infrastructure Networks, LLC"},
-	{"312 030", "Sprocket Wireless"},
+	{"312 030", "Bravado Wireless"},
 	{"312 040", "Custer Telephone Co-op (CTCI)"},
 	{"312 050", "Fuego Wireless"},
 	{"312 060", "CoverageCo"},
@@ -1348,7 +1403,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"312 320", "S and R Communications LLC"},
 	{"312 330", "Nemont"},
 	{"312 340", "MTA"},
-	{"312 350", "Triangle Communication Sytem Inc."},
+	{"312 350", "Triangle Communication System Inc."},
 	{"312 360", "Wes-Tex Telecommunications, Ltd."},
 	{"312 370", "Choice Wireless"},
 	{"312 380", "Copper Valley Wireless"},
@@ -1382,11 +1437,11 @@ const GSM_CodeName GSM_Networks[] = {
 	{"312 660", "nTelos"},
 	{"312 670", "AT&T"},
 	{"312 680", "AT&T"},
-	{"312 690", "Tecore Government Services, LLC"},
+	{"312 690", "TGS, LLC"},
 	{"312 700", "Wireless Partners, LLC"},
 	{"312 710", "Great North Woods Wireless LLC"},
 	{"312 720", "Southern LINC"},
-	{"312 730", "Triangle Communication Sytem Inc."},
+	{"312 730", "Triangle Communication System Inc."},
 	{"312 740", "Locus Telecommunications"},
 	{"312 750", "Artemis Networks LLC"},
 	{"312 760", "ASTAC"},
@@ -1414,7 +1469,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"312 980", "Mark Twain Communications Company"},
 	{"312 990", "Premier Broadband"},
 	{"313 000", "Tennessee Wireless "},
-	{"313 010", "Sprocket Wireless"},
+	{"313 010", "Bravado Wireless"},
 	{"313 020", "CTC Wireless"},
 	{"313 030", "Snake River PCS"},
 	{"313 040", "NNTC Wireless"},
@@ -1446,6 +1501,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"338 040", "Caricel"},
 	{"338 050", "Digicel"},
 	{"338 050", "Digicel"},
+	{"338 050", "Digicel"},
 	{"338 050", "Digicel Bermuda"},
 	{"338 070", "Claro"},
 	{"338 110", "FLOW"},
@@ -1460,6 +1516,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"340 20", "Digicel"},
 	{"342 600", "FLOW"},
 	{"342 750", "Digicel"},
+	{"342 800", "ozone"},
 	{"342 820", "Sunbeach Communications"},
 	{"344 030", "APUA"},
 	{"344 050", "Digicel"},
@@ -1474,13 +1531,15 @@ const GSM_CodeName GSM_Networks[] = {
 	{"350 00", "CellOne"},
 	{"350 01", "Digicel Bermuda"},
 	{"350 02", "Mobility"},
+	{"350 05", "Telecom Networks"},
+	{"350 11", "Deltronics"},
 	{"352 030", "Digicel"},
 	{"352 110", "FLOW"},
 	{"354 860", "FLOW"},
 	{"356 050", "Digicel"},
 	{"356 070", "Chippie"},
 	{"356 110", "FLOW"},
-	{"358 050", "Digicel{{Citation needed|date=August 2010}}"},
+	{"358 050", "Digicel"},
 	{"358 110", "FLOW"},
 	{"360 050", "Digicel"},
 	{"360 100", "Cingular Wireless"},
@@ -1503,15 +1562,15 @@ const GSM_CodeName GSM_Networks[] = {
 	{"363 01", "SETAR"},
 	{"363 02", "Digicel"},
 	{"364 39", "BTC"},
-	{"364 49", "NewCo 2015"},
+	{"364 49", "Aliv"},
 	{"365 010", "Weblinks Limited"},
 	{"365 840", "FLOW"},
 	{"366 020", "Digicel"},
 	{"366 110", "FLOW"},
 	{"368 01", "CUBACEL"},
-	{"370 01", "Orange"},
+	{"370 01", "Altice"},
 	{"370 02", "Claro"},
-	{"370 03", "Tricom"},
+	{"370 03", "Altice"},
 	{"370 04", "Viva"},
 	{"370 05", "Wind"},
 	{"372 01", "Voila"},
@@ -1748,13 +1807,13 @@ const GSM_CodeName GSM_Networks[] = {
 	{"405 917", "Etisalat DB(cheers)"},
 	{"405 927", "Uninor"},
 	{"405 929", "Uninor"},
-	{"410 01", "Mobilink"},
+	{"410 01", "Jazz"},
 	{"410 02", "PTCL"},
 	{"410 03", "Ufone"},
 	{"410 04", "Zong"},
 	{"410 05", "SCO Mobile"},
 	{"410 06", "Telenor"},
-	{"410 07", "Warid Pakistan"},
+	{"410 07", "Jazz"},
 	{"410 08", "SCO Mobile"},
 	{"412 01", "AWCC"},
 	{"412 20", "Roshan"},
@@ -1769,12 +1828,19 @@ const GSM_CodeName GSM_Networks[] = {
 	{"413 04", "Lanka Bell"},
 	{"413 05", "Airtel"},
 	{"413 08", "Hutch"},
+	{"413 11", "Dialog"},
+	{"413 12", "SLT"},
+	{"413 13", "Lanka Bell"},
+	{"414 00", "MPT"},
 	{"414 01", "MPT"},
+	{"414 02", "MPT"},
 	{"414 03", "CDMA800"},
+	{"414 04", "MPT"},
 	{"414 05", "Ooredoo"},
 	{"414 06", "Telenor"},
+	{"414 09", "MNTC"},
 	{"415 01", "Alfa"},
-	{"415 03", "touch"},
+	{"415 03", "Touch"},
 	{"415 05", "Ogero Mobile"},
 	{"416 01", "zain JO"},
 	{"416 02", "XPress Telecom"},
@@ -1819,6 +1885,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"425 06", "Wataniya Mobile"},
 	{"425 07", "Hot Mobile"},
 	{"425 08", "Golan Telecom"},
+	{"425 09", "018 Xphone"},
 	{"425 11", "365 Telecom"},
 	{"425 12", "Free Telecom"},
 	{"425 13", "Ituran Cellular Communications"},
@@ -1833,6 +1900,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"425 23", "Beezz Communication Solutions Ltd."},
 	{"425 24", "012 Telecom"},
 	{"425 25", "IMOD"},
+	{"425 26", "LB Annatel Ltd."},
 	{"425 28", "PHI Networks"},
 	{"426 01", "Batelco"},
 	{"426 02", "zain BH"},
@@ -1851,13 +1919,15 @@ const GSM_CodeName GSM_Networks[] = {
 	{"429 02", "Ncell"},
 	{"429 03", "UTL"},
 	{"429 04", "SmartCell"},
-	{"432 11", "IR-MCI (Hamrahe Avval)"},
+	{"432 08", "Shatel"},
+	{"432 11", "IR-MCI (Hamrah-e-Avval)"},
 	{"432 12", "Avacell"},
 	{"432 14", "TKC"},
 	{"432 19", "MTCE (Espadan)"},
 	{"432 20", "Rightel"},
 	{"432 32", "Taliya"},
 	{"432 35", "MTN Irancell"},
+	{"432 50", "Shatel"},
 	{"432 70", "TCI"},
 	{"432 93", "Iraphone"},
 	{"434 01", "Buztel"},
@@ -1873,6 +1943,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"436 03", "MegaFon"},
 	{"436 04", "Babilon-M"},
 	{"436 05", "Beeline"},
+	{"436 10", "Babilon-T"},
 	{"436 12", "Tcell"},
 	{"437 01", "Beeline"},
 	{"437 03", "Fonex"},
@@ -1884,7 +1955,10 @@ const GSM_CodeName GSM_Networks[] = {
 	{"440 00", "Y!Mobile"},
 	{"440 01", "UQ WiMAX"},
 	{"440 02", "Hanshin Cable Engineering Co., Ltd."},
+	{"440 03", "IIJmio"},
+	{"440 04", "Japan Radio Company, Ltd."},
 	{"440 05", "Wireless City Planning Inc."},
+	{"440 06", "SAKURA Internet Inc."},
 	{"440 10", "NTT docomo"},
 	{"440 20", "SoftBank"},
 	{"440 21", "SoftBank"},
@@ -1904,13 +1978,16 @@ const GSM_CodeName GSM_Networks[] = {
 	{"441 00", "Wireless City Planning Inc."},
 	{"441 01", "SoftBank"},
 	{"441 10", "UQ WiMAX"},
+	{"450 01", "Globalstar Asia Pacific"},
 	{"450 02", "KT"},
 	{"450 03", "Power 017"},
 	{"450 04", "KT"},
 	{"450 05", "SKTelecom"},
 	{"450 06", "LG U+"},
+	{"450 07", "KT"},
 	{"450 08", "olleh"},
 	{"450 11", "Korea Cable Telecom"},
+	{"450 12", "SKTelecom"},
 	{"452 01", "MobiFone"},
 	{"452 02", "Vinaphone"},
 	{"452 03", "S-Fone"},
@@ -1938,12 +2015,19 @@ const GSM_CodeName GSM_Networks[] = {
 	{"454 16", "PCCW Mobile (2G)"},
 	{"454 17", "SmarTone Mobile Communications Limited"},
 	{"454 18", "CSL Limited"},
-	{"454 19", "PCCW Mobile (3G/4G)"},
-	{"454 20", "PCCW-HKT"},
+	{"454 19", "PCCW Mobile (3G)"},
+	{"454 20", "PCCW Mobile (4G)"},
 	{"454 21", "21Vianet Mobile Ltd."},
-	{"454 22", "Delcom (HK) Ltd"},
+	{"454 22", "263 Mobile Communications (HongKong) Limited"},
 	{"454 23", "Lycamobile"},
+	{"454 24", "Multibyte Info Technology Ltd"},
+	{"454 25", "Hong Kong Government"},
+	{"454 26", "Hong Kong Government"},
 	{"454 29", "PCCW Mobile (CDMA)"},
+	{"454 30", "China Data Enterprises Ltd"},
+	{"454 31", "CTExcel"},
+	{"454 32", "Hong Kong Broadband Network Ltd"},
+	{"454 35", "Webbing Hong Kong Ltd"},
 	{"455 00", "SmarTone"},
 	{"455 01", "CTM"},
 	{"455 02", "China Telecom"},
@@ -2010,24 +2094,24 @@ const GSM_CodeName GSM_Networks[] = {
 	{"472 01", "Dhiraagu"},
 	{"472 02", "Ooredoo"},
 	{"502 01", "ATUR 450"},
-	{"502 10", "DiGi Telecommunications"},
+	{"502 10", "Maxis, DiGi, Celcom, XOX"},
 	{"502 11", "TM Homeline"},
 	{"502 12", "Maxis"},
 	{"502 13", "Celcom"},
 	{"502 14", "Telekom Malaysia Berhad for PSTN SMS"},
 	{"502 150", "Tune Talk"},
-	{"502 151", "Baraka Telecom Sdn Bhd (MVNE)"},
+	{"502 151", "SalamFone"},
 	{"502 152", "Yes"},
 	{"502 153", "Webe"},
 	{"502 154", "Tron"},
-	{"502 155", "Clixster Mobile Sdn Bhd"},
+	{"502 155", "Clixster"},
 	{"502 156", "Altel"},
-	{"502 157", "Telekomunikasi Indonesia International (M) Sdn Bhd"},
+	{"502 157", "Telin"},
 	{"502 16", "DiGi"},
-	{"502 17", "Hotlink"},
+	{"502 17", "Maxis"},
 	{"502 18", "U Mobile"},
 	{"502 19", "Celcom"},
-	{"502 20", "Electcoms Wireless Sdn Bhd"},
+	{"502 20", "Electcoms"},
 	{"505 01", "Telstra"},
 	{"505 02", "Optus"},
 	{"505 03", "Vodafone"},
@@ -2041,7 +2125,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"505 10", "Norfolk Telecom"},
 	{"505 11", "Telstra"},
 	{"505 12", "3"},
-	{"505 13", "Railcorp"},
+	{"505 13", "RailCorp"},
 	{"505 14", "AAPT"},
 	{"505 15", "3GIS"},
 	{"505 16", "VicTrack"},
@@ -2068,13 +2152,15 @@ const GSM_CodeName GSM_Networks[] = {
 	{"505 38", "Truphone"},
 	{"505 39", "Telstra"},
 	{"505 40", "CITIC Pacific Mining"},
-	{"505 41", "OTOC Australia Pty Ltd"},
-	{"505 61", "Commtel Network Solutions Pty Ltd"},
+	{"505 41", "Aqura Technologies Pty"},
+	{"505 42", "GEMCO"},
+	{"505 50", "Pivotel Group Pty Limited"},
+	{"505 61", "CommTel NS"},
 	{"505 62", "NBN"},
 	{"505 68", "NBN"},
 	{"505 71", "Telstra"},
 	{"505 72", "Telstra"},
-	{"505 88", "Localstar Holding Pty. Ltd."},
+	{"505 88", "Pivotel Group Pty Limited"},
 	{"505 90", "Optus"},
 	{"505 99", "One.Tel"},
 	{"510 00", "PSN"},
@@ -2087,7 +2173,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"510 11", "XL"},
 	{"510 20", "TELKOMMobile"},
 	{"510 21", "IM3"},
-	{"510 27", "Ceria"},
+	{"510 27", "Net1"},
 	{"510 28", "Fren/Hepi"},
 	{"510 88", "BOLT! Super 4G"},
 	{"510 89", "3"},
@@ -2103,7 +2189,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"515 18", "Cure"},
 	{"515 24", "ABS-CBN Mobile"},
 	{"515 88", "Next Mobile Inc."},
-	{"520 00", "my by CAT"},
+	{"520 00", "TrueMove H & my by CAT"},
 	{"520 01", "AIS"},
 	{"520 02", "CAT CDMA"},
 	{"520 03", "AIS"},
@@ -2123,6 +2209,8 @@ const GSM_CodeName GSM_Networks[] = {
 	{"525 06", "StarHub"},
 	{"525 07", "SingTel"},
 	{"525 08", "StarHub"},
+	{"525 09", "Circles.Life"},
+	{"525 10", "TPG Telecom Pte Ltd"},
 	{"525 12", "Grid"},
 	{"528 01", "Jabatan Telekom Brunei"},
 	{"528 02", "B-Mobile"},
@@ -2162,25 +2250,34 @@ const GSM_CodeName GSM_Networks[] = {
 	{"547 10", "Mara Telecom"},
 	{"547 15", "Vodafone"},
 	{"547 20", "Vini"},
-	{"548 01", "Kokanet"},
+	{"548 01", "Bluesky"},
 	{"549 01", "Digicel"},
 	{"549 27", "Bluesky"},
 	{"550 01", "FSMTC"},
 	{"551 01", "Marshall Islands National Telecommunications Authority (MINTA)"},
 	{"552 01", "PNCC"},
+	{"552 02", "PalauTel"},
 	{"552 80", "Palau Mobile"},
 	{"553 01", "TTC"},
+	{"554 01", "Teletok"},
 	{"555 01", "Telecom Niue"},
 	{"602 01", "Orange"},
 	{"602 02", "Vodafone"},
 	{"602 03", "Etisalat"},
+	{"602 04", "WE"},
 	{"603 01", "Mobilis"},
 	{"603 02", "Djezzy"},
 	{"603 03", "Ooredoo"},
+	{"603 07", "AT"},
+	{"603 09", "AT"},
+	{"603 21", "ANESRIF"},
 	{"604 00", "Orange Morocco"},
 	{"604 01", "IAM"},
-	{"604 02", "Wana Corporate"},
-	{"604 05", "INWI (Telecommunications)"},
+	{"604 02", "INWI"},
+	{"604 04", "Al Houria Telecom"},
+	{"604 05", "INWI"},
+	{"604 06", "IAM"},
+	{"604 99", "Al Houria Telecom"},
 	{"605 01", "Orange"},
 	{"605 02", "Tunicell"},
 	{"605 03", "OOREDOO TN"},
@@ -2218,7 +2315,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"612 07", "cafe"},
 	{"612 18", "YooMee"},
 	{"613 01", "Telmob"},
-	{"613 02", "Airtel"},
+	{"613 02", "Orange"},
 	{"613 03", "Telecel Faso"},
 	{"614 01", "SahelCom"},
 	{"614 02", "Airtel"},
@@ -2231,14 +2328,14 @@ const GSM_CodeName GSM_Networks[] = {
 	{"616 03", "MTN"},
 	{"616 04", "BBCOM"},
 	{"616 05", "Glo"},
-	{"617 01", "Orange"},
+	{"617 01", "my.t"},
 	{"617 02", "MOKOZE / AZU"},
 	{"617 03", "CHILI"},
 	{"617 10", "Emtel"},
 	{"618 01", "Lonestar Cell"},
 	{"618 02", "Libercell"},
 	{"618 04", "Novafone"},
-	{"618 07", "Cellcom"},
+	{"618 07", "Orange LBR"},
 	{"618 20", "LIBTELCO"},
 	{"619 01", "Airtel"},
 	{"619 02", "Africell"},
@@ -2252,9 +2349,9 @@ const GSM_CodeName GSM_Networks[] = {
 	{"619 50", "Datatel (SL) Ltd."},
 	{"620 01", "MTN"},
 	{"620 02", "Vodafone"},
-	{"620 03", "tiGO"},
+	{"620 03", "AirtelTigo"},
 	{"620 04", "Expresso"},
-	{"620 06", "Airtel"},
+	{"620 06", "AirtelTigo"},
 	{"620 07", "Globacom"},
 	{"620 08", "Surfline"},
 	{"620 10", "Blu"},
@@ -2269,7 +2366,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"621 30", "MTN"},
 	{"621 40", "Ntel"},
 	{"621 50", "Glo"},
-	{"621 60", "Etisalat"},
+	{"621 60", "9mobile"},
 	{"622 01", "Airtel"},
 	{"622 02", "Tawali"},
 	{"622 03", "Tigo"},
@@ -2284,6 +2381,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"625 01", "CVMOVEL"},
 	{"625 02", "T+"},
 	{"626 01", "CSTmovel"},
+	{"626 02", "Unitel STP"},
 	{"627 01", "Orange GQ"},
 	{"627 03", "Hits GQ"},
 	{"628 01", "Libertis"},
@@ -2328,6 +2426,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"637 01", "Telesom"},
 	{"637 04", "Somafone"},
 	{"637 10", "Nationlink"},
+	{"637 20", "SOMNET"},
 	{"637 30", "Golis"},
 	{"637 50", "Hormuud"},
 	{"637 57", "UNITEL"},
@@ -2340,7 +2439,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"639 02", "Safaricom"},
 	{"639 03", "Airtel"},
 	{"639 05", "yu"},
-	{"639 07", "Orange Kenya"},
+	{"639 07", "Telkom"},
 	{"640 01", "Rural NetCo Limited"},
 	{"640 02", "tiGO"},
 	{"640 03", "Zantel"},
@@ -2359,6 +2458,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"641 10", "MTN"},
 	{"641 11", "Uganda Telecom"},
 	{"641 14", "Africell"},
+	{"641 16", "SimbaNET Uganda Limited"},
 	{"641 18", "Smart"},
 	{"641 22", "Airtel"},
 	{"641 26", "Lycamobile"},
@@ -2385,7 +2485,9 @@ const GSM_CodeName GSM_Networks[] = {
 	{"646 04", "Telma"},
 	{"647 00", "Orange"},
 	{"647 01", "BJT Partners"},
-	{"647 02", "only"},
+	{"647 02", "Free"},
+	{"647 03", "Free"},
+	{"647 04", "4G Reunion"},
 	{"647 10", "SFR Reunion"},
 	{"648 01", "Net*One"},
 	{"648 03", "Telecel"},
@@ -2404,6 +2506,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"652 02", "Orange"},
 	{"652 04", "BTC Mobile"},
 	{"653 01", "SPTC"},
+	{"653 02", "Swazi Mobile Limited"},
 	{"653 10", "Swazi MTN"},
 	{"654 01", "HURI"},
 	{"654 02", "TELCO SA"},
@@ -2419,7 +2522,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"655 14", "Neotel"},
 	{"655 16", "Phoenix System Integration (Pty) Ltd"},
 	{"655 17", "Sishen Iron Ore Company (Ltd) Pty"},
-	{"655 19", "iBurst"},
+	{"655 19", "Wireless Business Solutions (Pty) Ltd"},
 	{"655 21", "Cape Town Metropolitan Council"},
 	{"655 24", "SMSPortal (Pty) Ltd."},
 	{"655 25", "Wirels Connect"},
@@ -2437,6 +2540,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"655 46", "SMS Cellular Services (Pty) Ltd"},
 	{"655 50", "Ericsson South Africa (Pty) Ltd"},
 	{"655 51", "Integrat (Pty) Ltd"},
+	{"655 53", "Lycamobile"},
 	{"655 73", "iBurst"},
 	{"655 74", "iBurst"},
 	{"657 01", "Eritel"},
@@ -2500,6 +2604,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"724 11", "Vivo"},
 	{"724 15", "Sercomtel"},
 	{"724 16", "Brasil Telecom GSM"},
+	{"724 17", "Correios"},
 	{"724 18", "datora"},
 	{"724 23", "Vivo"},
 	{"724 24", "Amazonia Celular"},
@@ -2517,10 +2622,10 @@ const GSM_CodeName GSM_Networks[] = {
 	{"724 99", "Local"},
 	{"730 01", "entel"},
 	{"730 02", "movistar"},
-	{"730 03", "Claro"},
+	{"730 03", "CLARO CL"},
 	{"730 04", "WOM"},
 	{"730 05", "Multikom S.A."},
-	{"730 06", "Telefonica del Sur"},
+	{"730 06", "Telsur"},
 	{"730 07", "movistar"},
 	{"730 08", "VTR Movil"},
 	{"730 09", "WOM"},
@@ -2534,6 +2639,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"730 17", "COMPATEL Chile Limitada"},
 	{"730 18", "Empresas Bunker S.A."},
 	{"730 19", "movil Falabella"},
+	{"730 20", "Inversiones Santa Fe Limitada"},
 	{"730 99", "Will"},
 	{"732 001", "movistar"},
 	{"732 002", "Edatel"},
@@ -2552,6 +2658,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"732 165", "Colombia Movil S.A. ESP"},
 	{"732 176", "DirecTV Colombia Ltda"},
 	{"732 187", "eTb"},
+	{"732 199", "SUMA Movil SAS"},
 	{"734 01", "Digitel"},
 	{"734 02", "Digitel GSM"},
 	{"734 03", "DirecTV"},
@@ -2567,6 +2674,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"740 00", "Movistar"},
 	{"740 01", "Claro"},
 	{"740 02", "CNT Mobile"},
+	{"740 03", "Tuenti"},
 	{"744 01", "VOX"},
 	{"744 02", "Claro/Hutchison"},
 	{"744 03", "Compania Privada de Comunicaciones S.A."},
@@ -2582,7 +2690,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"748 03", "Antel"},
 	{"748 07", "Movistar"},
 	{"748 10", "Claro"},
-	{"750 001", "sure"},
+	{"750 001", "Sure"},
 	{"901 01", "ICO"},
 	{"901 02", ""},
 	{"901 03", "Iridium"},
@@ -2598,7 +2706,7 @@ const GSM_CodeName GSM_Networks[] = {
 	{"901 13", "GSM.AQ"},
 	{"901 14", "AeroMobile"},
 	{"901 15", "OnAir"},
-	{"901 16", "Jasper Systems"},
+	{"901 16", "Cisco Jasper"},
 	{"901 17", "Navitas"},
 	{"901 18", "Cellular @Sea"},
 	{"901 19", "Vodafone Malta Maritime"},
@@ -2636,6 +2744,11 @@ const GSM_CodeName GSM_Networks[] = {
 	{"901 51", "VisionNG"},
 	{"901 52", "Manx Telecom Trading Ltd."},
 	{"901 53", "Deutsche Telekom AG"},
+	{"901 54", "Teleena Holding B.V."},
+	{"901 55", "Beezz Communication Solutions Ltd."},
+	{"901 56", "ETSI"},
+	{"901 57", "SAP"},
+	{"901 58", "BICS"},
 	{"901 88", "UN Office for the Coordination of Humanitarian Affairs (OCHA)"},
 	{"995 01", "FonePlus"},
 	{"999 99", "GammuTel"},
