@@ -1,5 +1,5 @@
 /* Copyright (c) 2002-2004 by Marcin Wiacek and Joergen Thomsen */
-/* Copyright (c) 2009 - 2017 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2018 Michal Cihar <michal@cihar.com> */
 
 #include <string.h>
 #include <signal.h>
@@ -401,6 +401,7 @@ GSM_SMSDConfig *SMSD_NewConfig(const char *name)
 	Config->RunOnFailure = NULL;
 	Config->RunOnSent = NULL;
 	Config->RunOnReceive = NULL;
+	Config->RunOnIncomingCall = NULL;
 	Config->smsdcfgfile = NULL;
 	Config->log_handle = NULL;
 	Config->log_type = SMSD_LOG_NONE;
@@ -1979,16 +1980,7 @@ void SMSD_IncomingCallCallback(GSM_StateMachine *s, GSM_Call *call, void *user_d
 			}
 
 			if (Config->RunOnIncomingCall != NULL) {
-#define BUFS 1024
-				char buf[BUFS];
-				int ret=0;
-				snprintf(buf, BUFS,"%s '%s'",
-					 Config->RunOnIncomingCall,
-					 DecodeUnicodeString(call->PhoneNumber));
-				ret = system(buf);
-				if (ret<0) {
-					SMSD_Log(DEBUG_ERROR, Config, "Incoming call -  could not run script: %s\n", strerror(errno) );
-				}
+				SMSD_RunOn(Config->RunOnIncomingCall, NULL, Config, DecodeUnicodeString(call->PhoneNumber), "incoming call");
 			}
 		}
 		break;
